@@ -441,6 +441,16 @@ func initialize() ([]store.KubeconfigStore, *types.Config, error) {
 				return nil, nil, fmt.Errorf("unable to create GKE store: %w", err)
 			}
 			s = gkeStore
+
+		case types.StoreKindAzure:
+			azureStore, err := store.NewAzureStore(kubeconfigStoreFromConfig, stateDirectory)
+			if err != nil {
+				if kubeconfigStoreFromConfig.Required != nil && !*kubeconfigStoreFromConfig.Required {
+					continue
+				}
+				return nil, nil, fmt.Errorf("unable to create Azure store: %w", err)
+			}
+			s = azureStore
 		default:
 			return nil, nil, fmt.Errorf("unknown store %q", kubeconfigStoreFromConfig.Kind)
 		}
@@ -467,7 +477,7 @@ func getStoreFromFlagAndEnv(config *types.Config) *types.KubeconfigStore {
 	pathsFromEnv := strings.Split(kubeconfigPathFromEnv, linuxEnvKubeconfigSeperator)
 
 	for _, path := range pathsFromEnv {
-		if !isDuplicatePath(config.KubeconfigStores, path) && !strings.HasSuffix(path, ".tmp") {
+		if !isDuplicatePath(config.KubeconfigStores, path) && !strings.HasSuffix(path, ".tmp") && path != "" {
 			// the KUBECONFIG env sets a unique, non kubeswitch set, env variable to a kubeconfig.
 			paths = append(paths, expandPath(path))
 			logrus.Debugf("Adding kubeconfig path from KUBECONFIG env %s", kubeconfigPathFromEnv)
