@@ -15,6 +15,7 @@
 package store
 
 import (
+	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice"
 	"github.com/danielfoehrkn/kubeswitch/types"
 	vaultapi "github.com/hashicorp/vault/api"
 	"github.com/sirupsen/logrus"
@@ -100,6 +101,7 @@ type GardenerStore struct {
 	SecretNamespaceNameToSecret map[string]corev1.Secret
 }
 
+// TODO: implement previewer interface
 type GKEStore struct {
 	Logger          *logrus.Entry
 	KubeconfigStore types.KubeconfigStore
@@ -114,3 +116,15 @@ type GKEStore struct {
 	ProjectNameToID map[string]string
 	StateDirectory  string
 }
+
+type AzureStore struct {
+	Logger          *logrus.Entry
+	KubeconfigStore types.KubeconfigStore
+	AksClient       *armcontainerservice.ManagedClustersClient
+	Config          *types.StoreConfigAzure
+	// DiscoveredClusters maps the kubeconfig path (az_<resource-group>--<cluster-name>) -> cluster
+	// This is a cache for the clusters discovered during the initial search for kubeconfig paths
+	// when not using a search index
+	DiscoveredClusters map[string]*armcontainerservice.ManagedCluster
+	StateDirectory     string
+}
